<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>DotPlotDialog</name>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="17"/>
        <source>Dotplot</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="30"/>
        <source>Dotplot parameters</source>
        <translation>Dotplot параметры</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="52"/>
        <source>Custom algorithm</source>
        <translation>Выбранный алгоритм</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="99"/>
        <source>X axis sequence</source>
        <translation>Последовательность оси X</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="112"/>
        <source>Minimum repeat length</source>
        <translation>Мин длина повторов</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="119"/>
        <source>Y axis sequence</source>
        <translation>Последовательность оси Y</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="126"/>
        <source>Repeats  identity</source>
        <translation>Идентичность повторов</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="151"/>
        <source>bp</source>
        <translation>нк</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="179"/>
        <source>Heuristic based selection of repeat length so the number of repeats in the sequence will not exceed 1000</source>
        <translation>Эвристический подбор длины повторов, с тем чтобы кол-во повторов в последовательности не превысило 1000</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="182"/>
        <source>1k</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="207"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="229"/>
        <source>Resets repeats identity to 100%</source>
        <translation>Сбросить к 100%</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="232"/>
        <source>100</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="287"/>
        <source>Search inverted repeats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="294"/>
        <source>Search direct repeats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="333"/>
        <location filename="../src/ui/DotPlotDialog.ui" line="340"/>
        <source>default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="365"/>
        <source>Click to load a sequence from the file system. The sequence will be added to the combo boxes when it is loaded to the project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="368"/>
        <source>Load Sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="393"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="403"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>DotPlotFilesDialog</name>
    <message>
        <source>Open sequences to build dotplot</source>
        <translation type="obsolete">Выберите последовательности для построения dotplot</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation type="obsolete">Имя файла:</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="48"/>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="142"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>Merge sequences</source>
        <translation type="obsolete">Объединить последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="23"/>
        <source>Build dotplot from sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="38"/>
        <source>File with first sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="55"/>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="149"/>
        <source>Join all sequences found in the file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="75"/>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="169"/>
        <source>Gap size:</source>
        <translation>Длина пропуска:</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="108"/>
        <source>Compare sequence against itself</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="128"/>
        <source>File with second sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="219"/>
        <source>Next</source>
        <translation>Далее</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="229"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>One sequence</source>
        <translation type="obsolete">Одна последовательность</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotDialog</name>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="63"/>
        <source>Auto</source>
        <translation>Автовыбор</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="64"/>
        <source>Suffix index</source>
        <translation>Суффиксный индекс</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="65"/>
        <source>Diagonals</source>
        <translation>Диагональный</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="274"/>
        <source>Open file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotDialogs</name>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="142"/>
        <source>Task is already running</source>
        <translation>Задача уже запущена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="142"/>
        <source>Build or Load DotPlot task is already running</source>
        <translation>Задача построения или загрузки dotplot уже запущена</translation>
    </message>
    <message>
        <source>Save DotPlot</source>
        <translation type="obsolete">Сохранить dotplot</translation>
    </message>
    <message>
        <source>Save DotPlot before deletion?</source>
        <translation type="obsolete">Сохранить dotplot перед удалением?</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="148"/>
        <source>Save dot-plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="148"/>
        <source>Save dot-plot data before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="154"/>
        <source>File opening error</source>
        <translation>Ошибка открытия файла</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="154"/>
        <source>Error opening file %1</source>
        <translation>Ошибка открытия файла %1</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="160"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="160"/>
        <source>Error opening files</source>
        <translation>Ошибка открытия файлов</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="166"/>
        <source>Sequences are different</source>
        <translation>Последовательности отличаются</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="166"/>
        <source>Current and loading sequences are different. Continue loading dot-plot anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="172"/>
        <source>Wrong dot-plot file format, loading aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="178"/>
        <source>Both sequence alphabets must be 4-symbols DNA alphabets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="184"/>
        <source>Too many results. Try to increase minimum repeat length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current and loading sequences are different. Continue loading DotPlot anyway?</source>
        <translation type="obsolete">Текущие и загружаемые последовательности отличаются. Продолжать загрузку dotplot?</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="172"/>
        <source>Wrong format</source>
        <translation>Неправильный формат</translation>
    </message>
    <message>
        <source>Wrong DotPlot file format, loading aborted</source>
        <translation type="obsolete">Неправильный формат файла dotplot, загрузка прервана</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="178"/>
        <source>Wrong alphabet types</source>
        <translation>Неправильные типы алфавитов</translation>
    </message>
    <message>
        <source>Both alphabets must be default DNA nucleotide</source>
        <translation type="obsolete">Оба алфавита должны быть стандартными алфавитами ДНК нуклеотидов</translation>
    </message>
    <message>
        <source>No project</source>
        <translation type="obsolete">Нет проекта</translation>
    </message>
    <message>
        <source>Create or load project first</source>
        <translation type="obsolete">Создайте или загрузите проект для начала</translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="184"/>
        <source>Too many results</source>
        <translation>Слишком много результатов</translation>
    </message>
    <message>
        <source>Too many results. Try to increase min length</source>
        <translation type="obsolete">Слишком много результатов. Попробуйте уменьшить минимальную длину повтора</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotFilesDialog</name>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="71"/>
        <source>Open first file</source>
        <translation>Открыть первый файл</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="88"/>
        <source>Open second file</source>
        <translation>Открыть второй файл</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="113"/>
        <source>Select files</source>
        <translation>Выберите файлы</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="113"/>
        <source>Select files first to build dotplot</source>
        <translation>Выберите файлы, чтобы посмотрить dotplot</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotLoadDocumentsTask</name>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="229"/>
        <source>DotPlot loading</source>
        <translation>Dotplot загружается</translation>
    </message>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="274"/>
        <source>Detecting format error for file %1</source>
        <translation>Ошибка определения формата файла %1</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotPlugin</name>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="57"/>
        <source>Dotplot</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="57"/>
        <source>Build dotplot for sequences</source>
        <translation>Построение dotplot для последовательностей</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotSplitter</name>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="52"/>
        <source>Multiple view synchronization lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="53"/>
        <source>Keep aspect ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="54"/>
        <source>Zoom in (&lt;b&gt; + &lt;/b&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="55"/>
        <source>Zoom out (&lt;b&gt; - &lt;/b&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="56"/>
        <source>Reset zooming (&lt;b&gt;0&lt;/b&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="57"/>
        <source>Select tool (&lt;b&gt;S&lt;/b&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="58"/>
        <source>Hand tool (&lt;b&gt;H&lt;/b&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotViewAction</name>
    <message>
        <location filename="../src/DotPlotPlugin.h" line="79"/>
        <source>Show dot plot</source>
        <translation>Показать dotplot</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotViewContext</name>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="79"/>
        <location filename="../src/DotPlotPlugin.cpp" line="205"/>
        <source>Build dotplot...</source>
        <translation>Построить dotplot...</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotWidget</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Настройки</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="109"/>
        <source>Parameters</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="112"/>
        <source>Save as image</source>
        <translation>Сохранить как изображение</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="115"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="118"/>
        <source>Load</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="121"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="183"/>
        <source>Save/Load</source>
        <translation>Сохранить/Загрузить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="916"/>
        <source> (min length %1, identity %2%)</source>
        <translation>(мин. длинна %1, идентичность %2%)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="182"/>
        <source>Dotplot</source>
        <translation></translation>
    </message>
    <message>
        <source>Save Dotplot image</source>
        <translation type="obsolete">Сохранение изображения dotplot</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation type="obsolete">Файлы изображений (*.png *.jpg *.bmp)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="441"/>
        <source>Save Dotplot</source>
        <translation>Сохранить dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="441"/>
        <location filename="../src/DotPlotWidget.cpp" line="487"/>
        <source>Dotplot files (*.dpt)</source>
        <translation>Файлы dotplot (*.dpt)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="487"/>
        <source>Load Dotplot</source>
        <translation>Загрузить dotplot</translation>
    </message>
</context>
<context>
    <name>U2::LoadDotPlotTask</name>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="62"/>
        <source>Wrong dotplot format</source>
        <translation>Неправильный формат файла dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotTasks.h" line="64"/>
        <source>DotPlot loading</source>
        <translation>Dotplot загружается</translation>
    </message>
</context>
<context>
    <name>U2::SaveDotPlotTask</name>
    <message>
        <location filename="../src/DotPlotTasks.h" line="40"/>
        <source>DotPlot saving</source>
        <translation>Dotplot сохраняется</translation>
    </message>
</context>
</TS>
